ReadGCAM
ReadGCAM.RdReadGCAM
Usage
ReadGCAM(
filetype,
input_path = NULL,
db_name = NULL,
query = system.file("extdata", "my_batch.xml", package = "GCAMUSAJobs"),
scen_name = NULL,
prj_name = NULL
)Arguments
- filetype
specify the input is a database (folder) or a project (.dat)
- input_path
specify the full path for the input file
- db_name
specify the database name
- query
use the default query file in the package "my_batch.xml"
- scen_name
specify the scenario name (this needs to match the scenario name specified in the DB)
- prj_name
specify the project (.dat) name either to name it or load the existed one
Examples
if (FALSE) { # \dontrun{
prj <- ReadGCAM(filetype = 'db',
input_path = "C:/GODEEP/GCAM7/output",
db_name = "database_basexdbGCAM-USA_Ref",
query = system.file("extdata", "my_batch.xml", package = "GCAMUSAJobs"),
scen_name = "GCAM-USA_Ref",
prj_name = "mydata.dat")
} # }