read raw csv files from inst/extdata/GCAM folder
Usage
read.GCAM.csv(basename, na.strings = "")
Arguments
- basename
name of the file to be read in, without .csv
- na.strings
set to ""
Value
A data frame from raw csv file saved in the inst/extdata/GCAM folder
Examples
if (FALSE) { # \dontrun{
A23.globaltech_retirement <- read.GCAM.csv("A23.globaltech_retirement")
} # }